#ifndef bqtStmtHH
#define bqtStmtHH

#include <list>

#include "autoptr"
#include "tokens.hh"
#include "expr.hh"

class stmt: public ptrable
{
public:
    stmt();
    virtual ~stmt();
    
};

typedef autoptr<stmt> stmtp;

class stmt_if: public stmt
{
public:
    exprp condition;
    stmtp thenp;
    std::list<
        std::pair<exprp, stmtp>
             > elseifp;
    stmtp elsep;
public:
};
class stmt_dowhile: public stmt
{
    exprp precondition;
    exprp postcondition;
    stmtp bodyp;
public:
};
class stmt_for: public stmt
{
    exprp var;
    exprp begin, end, step;
public:
};
class stmt_select: public stmt
{
    exprp ref;
    std::list<
        std::pair<exprp, stmtp>
             > cases;
public:
};
class stmt_return: public stmt
{
    QBtoken token;
    // return type: RETURN, EXITDEF, EXITDO, EXITSUB, EXITFUNCTION, EXITFOR
public:
};
class stmt_goto: public stmt
{
    exprp label;
public:
    stmt_goto(exprp l) : label(l) { }
};
class stmt_restore: public stmt
{
    unsigned dataptr;
public:
    stmt_restore(unsigned p): dataptr(p) { }
};
class stmt_read: public stmt
{
    exprp target;
public:
    stmt_read(exprp t) : target(t) { }
};


class stmt_fileopen: public stmt
{
    exprp filename;
    QBtoken mode;
    exprp mode_str;
    int access;
    int locking;
    exprp reclen;
public:
    stmt_fileopen(exprp fn, exprp mstr, int ac, int lk, exprp rl) 
        : filename(fn), mode_str(mstr), access(ac), locking(lk), reclen(rl)
    {
    }
    stmt_fileopen(exprp fn, QBtoken md, int ac, int lk, exprp rl) 
        : filename(fn), mode(md), access(ac), locking(lk), reclen(rl)
    {
    }
};
#endif
